@@ -12,6 +12,17 @@ pub struct Order {
     pub api_key: common::ApiKey,
 }
 
+impl Order {
+    /// Order is empty if it does not include and payment plans.
+    pub fn is_empty(&self) -> bool {
+        self.items.iter().all(|(_, all_package_plans)| {
+            all_package_plans
+                .iter()
+                .all(|package_plans| package_plans.plans.is_empty())
+        })
+    }
+}
+
 #[derive(Debug, serde::Deserialize, serde::Serialize)]
 pub struct PackagePlans {
     pub package: crate::package::Package,
@@ -22,7 +33,7 @@ pub struct PackagePlans {
 #[derive(Debug, serde::Deserialize, serde::Serialize)]
 pub struct Plan {
     pub plan_id: String,
-    pub plan: crate::lock::plan::PaymentPlan,
+    pub plan: crate::lock::plan::Plan,
 }
 
 #[derive(Debug, serde::Deserialize, serde::Serialize)]
