@@ -17,13 +17,13 @@ pub struct Conditions {
 }
 
 impl Conditions {
-    pub fn evaluate(&self, config: &crate::config::Config) -> Result<bool> {
+    pub fn evaluate(&self, parameters: &crate::lock::plan::conditions::Parameters) -> Result<bool> {
         let mut all_conditions_pass = true;
         if let Some(current_time) = &self.current_time {
             all_conditions_pass &= current_time.evaluate()?;
         }
         if let Some(employees_count) = &self.employees_count {
-            all_conditions_pass &= employees_count.evaluate(&config)?;
+            all_conditions_pass &= employees_count.evaluate(&parameters)?;
         }
         Ok(all_conditions_pass)
     }
@@ -37,3 +37,22 @@ impl Conditions {
         }
     }
 }
+
+#[derive(Debug, Clone, Ord, PartialOrd, Eq, PartialEq, serde::Serialize, serde::Deserialize)]
+pub struct Parameters {
+    #[serde(rename = "employees-count")]
+    pub employees_count: Option<usize>,
+    pub commercial: bool,
+    #[serde(rename = "include-voluntary-donations")]
+    pub include_voluntary_plans: bool,
+}
+
+impl std::default::Default for Parameters {
+    fn default() -> Self {
+        Self {
+            employees_count: None,
+            commercial: true,
+            include_voluntary_plans: true,
+        }
+    }
+}
